summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAnup Patel <apatel@ventanamicro.com>2021-06-15 09:07:59 +0300
committerAnup Patel <anup@brainfault.org>2022-02-15 18:09:15 +0300
commit8e2ef4f7af5affebc8464dd9c4b98501df14e23e (patch)
tree7821f559de010fca95c59cb5d84740e6f549ba23 /include
parent34612193af92f29446a3d59bc4f983c9cfe4b989 (diff)
downloadopensbi-8e2ef4f7af5affebc8464dd9c4b98501df14e23e.tar.xz
lib: utils: Disable appropriate APLIC DT nodes in fdt_fixups()
We should disable APLIC DT nodes in fdt_fixups() which are not accessible to the next booting stage based on currently assigned domain. Signed-off-by: Anup Patel <anup.patel@wdc.com> Signed-off-by: Anup Patel <apatel@ventanamicro.com> Reviewed-by: Atish Patra <atishp@rivosinc.com>
Diffstat (limited to 'include')
-rw-r--r--include/sbi_utils/fdt/fdt_fixup.h18
1 files changed, 15 insertions, 3 deletions
diff --git a/include/sbi_utils/fdt/fdt_fixup.h b/include/sbi_utils/fdt/fdt_fixup.h
index 77575bb..fb076ba 100644
--- a/include/sbi_utils/fdt/fdt_fixup.h
+++ b/include/sbi_utils/fdt/fdt_fixup.h
@@ -22,6 +22,18 @@
void fdt_cpu_fixup(void *fdt);
/**
+ * Fix up the APLIC nodes in the device tree
+ *
+ * This routine disables APLIC nodes which are not accessible to the next
+ * booting stage based on currently assigned domain.
+ *
+ * It is recommended that platform codes call this helper in their final_init()
+ *
+ * @param fdt: device tree blob
+ */
+void fdt_aplic_fixup(void *fdt);
+
+/**
* Fix up the IMSIC nodes in the device tree
*
* This routine disables IMSIC nodes which are not accessible to the next
@@ -76,9 +88,9 @@ int fdt_reserved_memory_nomap_fixup(void *fdt);
* General device tree fix-up
*
* This routine do all required device tree fix-ups for a typical platform.
* It fixes up the PLIC node, IMSIC nodes, and the reserved memory node in
* the device tree by calling the corresponding helper routines to accomplish
* the task.
*
* It is recommended that platform codes call this helper in their final_init()
*
@@ -76,9 +88,9 @@ int fdt_reserved_memory_nomap_fixup(void *fdt);
*
* This routine do all required device tree fix-ups for a typical platform.
- * It fixes up the PLIC node, IMSIC nodes, and the reserved memory node in
- * the device tree by calling the corresponding helper routines to accomplish
- * the task.
+ * It fixes up the PLIC node, IMSIC nodes, APLIC nodes, and the reserved
+ * memory node in the device tree by calling the corresponding helper
+ * routines to accomplish the task.
*
* It is recommended that platform codes call this helper in their final_init()